@@ -199,6 +199,30 @@ pub fn op_name(op: u8) -> &'static str {
         ops::CMPS_REG_ADDR_WORD => names::op::CMPS_REG_ADDR_WORD,
         ops::JRF_BYTE => names::op::JRF_BYTE,
         ops::JRB_BYTE => names::op::JRB_BYTE,
+        ops::ADDC_REG_REG_BYTE => names::op::ADDC_REG_REG_BYTE,
+        ops::ADDC_REG_REG_WORD => names::op::ADDC_REG_REG_WORD,
+        ops::ADDC_REG_NUM_BYTE => names::op::ADDC_REG_NUM_BYTE,
+        ops::ADDC_REG_NUM_WORD => names::op::ADDC_REG_NUM_WORD,
+        ops::ADDC_REG_ADDR_BYTE => names::op::ADDC_REG_ADDR_BYTE,
+        ops::ADDC_REG_ADDR_WORD => names::op::ADDC_REG_ADDR_WORD,
+        ops::ADDC_ADDR_REG_BYTE => names::op::ADDC_ADDR_REG_BYTE,
+        ops::ADDC_ADDR_REG_WORD => names::op::ADDC_ADDR_REG_WORD,
+        ops::ADDC_ADDR_NUM_BYTE => names::op::ADDC_ADDR_NUM_BYTE,
+        ops::ADDC_ADDR_NUM_WORD => names::op::ADDC_ADDR_NUM_WORD,
+        ops::ADDC_ADDR_ADDR_BYTE => names::op::ADDC_ADDR_ADDR_BYTE,
+        ops::ADDC_ADDR_ADDR_WORD => names::op::ADDC_ADDR_ADDR_WORD,
+        ops::SUBC_REG_REG_BYTE => names::op::SUBC_REG_REG_BYTE,
+        ops::SUBC_REG_REG_WORD => names::op::SUBC_REG_REG_WORD,
+        ops::SUBC_REG_NUM_BYTE => names::op::SUBC_REG_NUM_BYTE,
+        ops::SUBC_REG_NUM_WORD => names::op::SUBC_REG_NUM_WORD,
+        ops::SUBC_REG_ADDR_BYTE => names::op::SUBC_REG_ADDR_BYTE,
+        ops::SUBC_REG_ADDR_WORD => names::op::SUBC_REG_ADDR_WORD,
+        ops::SUBC_ADDR_REG_BYTE => names::op::SUBC_ADDR_REG_BYTE,
+        ops::SUBC_ADDR_REG_WORD => names::op::SUBC_ADDR_REG_WORD,
+        ops::SUBC_ADDR_NUM_BYTE => names::op::SUBC_ADDR_NUM_BYTE,
+        ops::SUBC_ADDR_NUM_WORD => names::op::SUBC_ADDR_NUM_WORD,
+        ops::SUBC_ADDR_ADDR_BYTE => names::op::SUBC_ADDR_ADDR_BYTE,
+        ops::SUBC_ADDR_ADDR_WORD => names::op::SUBC_ADDR_ADDR_WORD,
         _ => panic!("Unknown: {:02X}", op),
     }
 }
@@ -393,6 +417,30 @@ pub fn op_desc(op: u8) -> &'static str {
         ops::CMPS_REG_ADDR_WORD => names::full::CMPS_REG_ADDR_WORD,
         ops::JRF_BYTE => names::full::JRF_BYTE,
         ops::JRB_BYTE => names::full::JRB_BYTE,
+        ops::ADDC_REG_REG_BYTE => names::full::ADDC_REG_REG_BYTE,
+        ops::ADDC_REG_REG_WORD => names::full::ADDC_REG_REG_WORD,
+        ops::ADDC_REG_NUM_BYTE => names::full::ADDC_REG_NUM_BYTE,
+        ops::ADDC_REG_NUM_WORD => names::full::ADDC_REG_NUM_WORD,
+        ops::ADDC_REG_ADDR_BYTE => names::full::ADDC_REG_ADDR_BYTE,
+        ops::ADDC_REG_ADDR_WORD => names::full::ADDC_REG_ADDR_WORD,
+        ops::ADDC_ADDR_REG_BYTE => names::full::ADDC_ADDR_REG_BYTE,
+        ops::ADDC_ADDR_REG_WORD => names::full::ADDC_ADDR_REG_WORD,
+        ops::ADDC_ADDR_NUM_BYTE => names::full::ADDC_ADDR_NUM_BYTE,
+        ops::ADDC_ADDR_NUM_WORD => names::full::ADDC_ADDR_NUM_WORD,
+        ops::ADDC_ADDR_ADDR_BYTE => names::full::ADDC_ADDR_ADDR_BYTE,
+        ops::ADDC_ADDR_ADDR_WORD => names::full::ADDC_ADDR_ADDR_WORD,
+        ops::SUBC_REG_REG_BYTE => names::full::SUBC_REG_REG_BYTE,
+        ops::SUBC_REG_REG_WORD => names::full::SUBC_REG_REG_WORD,
+        ops::SUBC_REG_NUM_BYTE => names::full::SUBC_REG_NUM_BYTE,
+        ops::SUBC_REG_NUM_WORD => names::full::SUBC_REG_NUM_WORD,
+        ops::SUBC_REG_ADDR_BYTE => names::full::SUBC_REG_ADDR_BYTE,
+        ops::SUBC_REG_ADDR_WORD => names::full::SUBC_REG_ADDR_WORD,
+        ops::SUBC_ADDR_REG_BYTE => names::full::SUBC_ADDR_REG_BYTE,
+        ops::SUBC_ADDR_REG_WORD => names::full::SUBC_ADDR_REG_WORD,
+        ops::SUBC_ADDR_NUM_BYTE => names::full::SUBC_ADDR_NUM_BYTE,
+        ops::SUBC_ADDR_NUM_WORD => names::full::SUBC_ADDR_NUM_WORD,
+        ops::SUBC_ADDR_ADDR_BYTE => names::full::SUBC_ADDR_ADDR_BYTE,
+        ops::SUBC_ADDR_ADDR_WORD => names::full::SUBC_ADDR_ADDR_WORD,
         _ => panic!("Unknown: {:02X}", op),
     }
 }
