@@ -199,6 +199,30 @@ pub mod op {
     pub const CMPS_REG_ADDR_WORD: &str = "CMPS.W";
     pub const JRB_BYTE: &str = "JRB";
     pub const JRF_BYTE: &str = "JRF";
+    pub const ADDC_REG_REG_BYTE: &str = "ADDC.B";
+    pub const ADDC_REG_REG_WORD: &str = "ADDC.W";
+    pub const ADDC_REG_NUM_BYTE: &str = "ADDC.B";
+    pub const ADDC_REG_NUM_WORD: &str = "ADDC.W";
+    pub const ADDC_REG_ADDR_BYTE: &str = "ADDC.B";
+    pub const ADDC_REG_ADDR_WORD: &str = "ADDC.W";
+    pub const ADDC_ADDR_REG_BYTE: &str = "ADDC.B";
+    pub const ADDC_ADDR_REG_WORD: &str = "ADDC.W";
+    pub const ADDC_ADDR_NUM_BYTE: &str = "ADDC.B";
+    pub const ADDC_ADDR_NUM_WORD: &str = "ADDC.W";
+    pub const ADDC_ADDR_ADDR_BYTE: &str = "ADDC.B";
+    pub const ADDC_ADDR_ADDR_WORD: &str = "ADDC.W";
+    pub const SUBC_REG_REG_BYTE: &str = "SUBC.B";
+    pub const SUBC_REG_REG_WORD: &str = "SUBC.W";
+    pub const SUBC_REG_NUM_BYTE: &str = "SUBC.B";
+    pub const SUBC_REG_NUM_WORD: &str = "SUBC.W";
+    pub const SUBC_REG_ADDR_BYTE: &str = "SUBC.B";
+    pub const SUBC_REG_ADDR_WORD: &str = "SUBC.W";
+    pub const SUBC_ADDR_REG_BYTE: &str = "SUBC.B";
+    pub const SUBC_ADDR_REG_WORD: &str = "SUBC.W";
+    pub const SUBC_ADDR_NUM_BYTE: &str = "SUBC.B";
+    pub const SUBC_ADDR_NUM_WORD: &str = "SUBC.W";
+    pub const SUBC_ADDR_ADDR_BYTE: &str = "SUBC.B";
+    pub const SUBC_ADDR_ADDR_WORD: &str = "SUBC.W";
 }
 
 pub mod full {
@@ -390,4 +414,28 @@ pub mod full {
     pub const CMPS_REG_ADDR_WORD: &str = "CMPS.W (R,A)";
     pub const JRB_BYTE: &str = "JRB (N)";
     pub const JRF_BYTE: &str = "JRF (N)";
+    pub const ADDC_REG_REG_BYTE: &str = "ADDC.B (R,R)";
+    pub const ADDC_REG_REG_WORD: &str = "ADDC.W (R,R)";
+    pub const ADDC_REG_NUM_BYTE: &str = "ADDC.B (R,N)";
+    pub const ADDC_REG_NUM_WORD: &str = "ADDC.W (R,N)";
+    pub const ADDC_REG_ADDR_BYTE: &str = "ADDC.B (R,A)";
+    pub const ADDC_REG_ADDR_WORD: &str = "ADDC.W (R,A)";
+    pub const ADDC_ADDR_REG_BYTE: &str = "ADDC.B (A,R)";
+    pub const ADDC_ADDR_REG_WORD: &str = "ADDC.W (A,R)";
+    pub const ADDC_ADDR_NUM_BYTE: &str = "ADDC.B (A,N)";
+    pub const ADDC_ADDR_NUM_WORD: &str = "ADDC.W (A,N)";
+    pub const ADDC_ADDR_ADDR_BYTE: &str = "ADDC.B (A,A)";
+    pub const ADDC_ADDR_ADDR_WORD: &str = "ADDC.W (A,A)";
+    pub const SUBC_REG_REG_BYTE: &str = "SUBC.B (R,R)";
+    pub const SUBC_REG_REG_WORD: &str = "SUBC.W (R,R)";
+    pub const SUBC_REG_NUM_BYTE: &str = "SUBC.B (R,N)";
+    pub const SUBC_REG_NUM_WORD: &str = "SUBC.W (R,N)";
+    pub const SUBC_REG_ADDR_BYTE: &str = "SUBC.B (R,A)";
+    pub const SUBC_REG_ADDR_WORD: &str = "SUBC.W (R,A)";
+    pub const SUBC_ADDR_REG_BYTE: &str = "SUBC.B (A,R)";
+    pub const SUBC_ADDR_REG_WORD: &str = "SUBC.W (A,R)";
+    pub const SUBC_ADDR_NUM_BYTE: &str = "SUBC.B (A,N)";
+    pub const SUBC_ADDR_NUM_WORD: &str = "SUBC.W (A,N)";
+    pub const SUBC_ADDR_ADDR_BYTE: &str = "SUBC.B (A,A)";
+    pub const SUBC_ADDR_ADDR_WORD: &str = "SUBC.W (A,A)";
 }
