@@ -26,10 +26,16 @@ pub fn get_byte_count(op: u8) -> usize {
         | ASL_ADDR_BYTE | ASR_ADDR_BYTE | LSR_ADDR_BYTE | ROL_ADDR_BYTE | LSR_REG_REG_BYTE
         | ROR_ADDR_BYTE | MUL_REG_NUM_BYTE | MULS_REG_NUM_BYTE | JGE_ADDR
         | JBS_REG_NUM | JBS_REG_REG | JBC_REG_NUM | JBC_REG_REG
+        | ADDC_REG_REG_BYTE | ADDC_REG_REG_WORD | ADDC_REG_NUM_BYTE
+        | SUBC_REG_REG_BYTE | SUBC_REG_REG_WORD | SUBC_REG_NUM_BYTE
         | DIVS_REG_NUM_BYTE | MUL_REG_REG_BYTE | MULS_REG_REG_BYTE | DIV_REG_REG_BYTE
         | DIVS_REG_REG_BYTE | MUL_REG_REG_WORD | MULS_REG_REG_WORD | DIV_REG_REG_WORD
         | DIVS_REG_REG_WORD | JMP_ADDR | JL_ADDR | JG_ADDR | JLE_ADDR => 2,
         LSR_REG_NUM_WORD | ROL_REG_NUM_WORD | DIVS_REG_ADDR_WORD | JBS_ADDR_REG
+        | ADDC_REG_NUM_WORD | ADDC_REG_ADDR_BYTE | ADDC_REG_ADDR_WORD | ADDC_ADDR_REG_WORD
+        | ADDC_ADDR_REG_BYTE | ADDC_ADDR_NUM_BYTE
+        | SUBC_REG_NUM_WORD | SUBC_REG_ADDR_BYTE | SUBC_REG_ADDR_WORD | SUBC_ADDR_REG_WORD
+        | SUBC_ADDR_REG_BYTE | SUBC_ADDR_NUM_BYTE
         | ROR_REG_NUM_WORD | CMPS_REG_ADDR_WORD | MULS_REG_ADDR_WORD | JBS_ADDR_NUM | JBC_ADDR_NUM
         | CMP_REG_ADDR_WORD | CMPS_REG_ADDR_BYTE | CMP_REG_ADDR_BYTE | DIV_REG_ADDR_WORD
         | CMPS_REG_NUM_WORD | CMP_REG_NUM_WORD | MUL_REG_ADDR_WORD | JBC_ADDR_REG
@@ -45,6 +51,8 @@ pub fn get_byte_count(op: u8) -> usize {
         | DIVS_ADDR_NUM_BYTE | MUL_REG_NUM_WORD | MULS_REG_NUM_WORD | DIV_REG_NUM_WORD
         | DIVS_REG_NUM_WORD | MUL_REG_ADDR_BYTE | MULS_REG_ADDR_BYTE | DIV_REG_ADDR_BYTE => 3,
         CPY_ADDR_NUM_WORD | CPY_ADDR_ADDR_BYTE | CPY_ADDR_ADDR_WORD | ADD_ADDR_ADDR_WORD
+        | ADDC_ADDR_ADDR_BYTE | ADDC_ADDR_ADDR_WORD | ADDC_ADDR_NUM_WORD
+        | SUBC_ADDR_ADDR_BYTE | SUBC_ADDR_ADDR_WORD | SUBC_ADDR_NUM_WORD
         | MUL_ADDR_NUM_WORD | MULS_ADDR_NUM_WORD | DIV_ADDR_NUM_WORD | DIVS_ADDR_NUM_WORD
         | ADD_ADDR_ADDR_BYTE | ADD_ADDR_NUM_WORD | SUB_ADDR_ADDR_WORD | SUB_ADDR_ADDR_BYTE
         | MUL_ADDR_ADDR_BYTE | MUL_ADDR_ADDR_WORD | MULS_ADDR_ADDR_BYTE | MEM_CPY_ADDR_REG_BYTE
@@ -259,9 +267,36 @@ pub const JBC_REG_NUM: u8 = 0xCC;
 pub const JBS_REG_NUM: u8 = 0xCD;
 pub const JBC_ADDR_NUM: u8 = 0xCE;
 pub const JBS_ADDR_NUM: u8 = 0xCF;
+//unused 16 0xD0 - 0xDF
+
+pub const ADDC_REG_REG_BYTE: u8 = 0xE0;
+pub const ADDC_REG_REG_WORD: u8 = 0xE1;
+pub const ADDC_REG_NUM_BYTE: u8 = 0xE2;
+pub const ADDC_REG_NUM_WORD: u8 = 0xE3;
+pub const ADDC_REG_ADDR_BYTE: u8 = 0xE4;
+pub const ADDC_REG_ADDR_WORD: u8 = 0xE5;
+pub const ADDC_ADDR_REG_BYTE: u8 = 0xE6;
+pub const ADDC_ADDR_REG_WORD: u8 = 0xE7;
+pub const ADDC_ADDR_NUM_BYTE: u8 = 0xE8;
+pub const ADDC_ADDR_NUM_WORD: u8 = 0xE9;
+pub const ADDC_ADDR_ADDR_BYTE: u8 = 0xEA;
+pub const ADDC_ADDR_ADDR_WORD: u8 = 0xEB;
+pub const SUBC_REG_REG_BYTE: u8 = 0xEC;
+pub const SUBC_REG_REG_WORD: u8 = 0xED;
+pub const SUBC_REG_NUM_BYTE: u8 = 0xEE;
+pub const SUBC_REG_NUM_WORD: u8 = 0xEF;
+pub const SUBC_REG_ADDR_BYTE: u8 = 0xF0;
+pub const SUBC_REG_ADDR_WORD: u8 = 0xF1;
+pub const SUBC_ADDR_REG_BYTE: u8 = 0xF2;
+pub const SUBC_ADDR_REG_WORD: u8 = 0xF3;
+pub const SUBC_ADDR_NUM_BYTE: u8 = 0xF4;
+pub const SUBC_ADDR_NUM_WORD: u8 = 0xF5;
+pub const SUBC_ADDR_ADDR_BYTE: u8 = 0xF6;
+pub const SUBC_ADDR_ADDR_WORD: u8 = 0xF7;
+//unused 8 0xF8 - 0xFF
 
 #[rustfmt::skip]
-pub const ALL: [u8; 188] = [
+pub const ALL: [u8; 212] = [
     NOP, HALT,
     CALL_ADDR, CALL_REG, RET, RETI,
     CPY_REG_REG_BYTE, CPY_REG_REG_WORD, CPY_ADDR_REG_BYTE, CPY_ADDR_REG_WORD,
@@ -313,7 +348,13 @@ pub const ALL: [u8; 188] = [
     CMP_REG_ADDR_BYTE, CMP_REG_ADDR_WORD, CMPS_REG_ADDR_BYTE, CMPS_REG_ADDR_WORD,
     JBS_REG_REG, JBS_REG_NUM, JBS_ADDR_REG, JBS_ADDR_NUM,
     JBC_REG_REG, JBC_REG_NUM, JBC_ADDR_REG, JBC_ADDR_NUM,
-    JRF_BYTE, JRB_BYTE
+    JRF_BYTE, JRB_BYTE,
+    ADDC_REG_REG_BYTE, ADDC_REG_REG_WORD, ADDC_REG_NUM_BYTE, ADDC_REG_NUM_WORD,
+    ADDC_REG_ADDR_BYTE, ADDC_REG_ADDR_WORD, ADDC_ADDR_REG_BYTE, ADDC_ADDR_REG_WORD,
+    ADDC_ADDR_NUM_BYTE, ADDC_ADDR_NUM_WORD, ADDC_ADDR_ADDR_BYTE, ADDC_ADDR_ADDR_WORD,
+    SUBC_REG_REG_BYTE, SUBC_REG_REG_WORD, SUBC_REG_NUM_BYTE, SUBC_REG_NUM_WORD,
+    SUBC_REG_ADDR_BYTE, SUBC_REG_ADDR_WORD, SUBC_ADDR_REG_BYTE, SUBC_ADDR_REG_WORD,
+    SUBC_ADDR_NUM_BYTE, SUBC_ADDR_NUM_WORD, SUBC_ADDR_ADDR_BYTE, SUBC_ADDR_ADDR_WORD,
 ];
 
 #[cfg(test)]
